/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004-2008.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Requirements, changes, info for this class (not complete list...):
 *
 *  bug #58470: FTS: make syslog facility configurable
 *     (https://savannah.cern.ch/bugs/?58470)
 *
 *  Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
 *           Zsolt Molnar <zsolt.molnar@cern.ch - http://www.zsoltmolnar.hu>
 *  Version info: $Id: SysLogInfo.h,v 1.2 2009/12/11 17:51:35 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_CONF_SERVICE_SYSLOGINFO_H_
#define GLITE_DATA_CONF_SERVICE_SYSLOGINFO_H_

#include <string>

namespace glite {
namespace config {

/**
 * SysLogInfo
 * Common information for SysLog objects
 */
class SysLogInfo
{
public:
    /**
     * Singleton instance
     * @return singleton instance
     */
    static SysLogInfo& instance();
    
    /**
     * Configure the instance
     * @param serviceName [IN] the name of the service
     */
    void configure(
        const std::string& serviceName,
        const std::string& syslogIdent,
        const int syslogFacility,
        const std::string& syslogFacilityName);
    
    /**
     * Reonfigure the instance
     * @param serviceName [IN] the name of the service
     */
    void reconfigure(
        const std::string& serviceName,
        const std::string& syslogIdent,
        const int syslogFacility,
        const std::string& syslogFacilityName);

    /**
     * configured
     * @return configuration flag
     */
    bool configured()
    {
        return m_configured;
    }
    
    /**
     * serviceName
     * @return the service name
     */
    const std::string& serviceName()
    {
        return m_serviceName;
    }

    /**
     * serviceId
     * @return the service id to use for logging (i.e. <name>[<pid>])
     */
    const std::string& serviceId()
    {
        return m_serviceId;
    }
        
    /**
     * pid
     * @return the process id
     */
    pid_t pid()
    {
        return m_pid;
    }
    
    int getFacility() const;
    const std::string& getFacilityName() const;
    const std::string& getIdent() const;

private:
    SysLogInfo();
    // configuration flag
    bool m_configured;
    // the name of the service
    std::string m_serviceName;
    // the id of the service to use for logging (i.e. <name>[<pid>])
    std::string m_serviceId;
    // the process id
    pid_t m_pid;
    std::string m_syslogIdent;
    int m_syslogFacility;
    std::string m_syslogFacilityName;
};

} // namespace config
} // namespace glite

#endif // GLITE_DATA_CONF_SERVICE_SYSLOGINFO_H_
