/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * glite-config.h
 *
 * Authors: Paolo Badino <paolo.badino@cern.ch>
 * Version info: $Id: glite-config.h,v 1.8 2008/01/24 08:43:43 ptedesco Exp $
 * Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_CONFIG_GLITE_CONF_H_
#define GLITE_DATA_CONFIG_GLITE_CONF_H_

#ifdef __cplusplus
extern "C" {
#endif //__cplusplus

/**
 * Initialize the Service using Glite Configuration
 * @param name [IN] the service name
 * @return 0 if success, 1 if already initialized, -1 if failed
 */
int glite_config_initialize(const char * name);
    
/**
 * Reconfigure the Service using Glite Configuration
 * @param name [IN] the service name
 * @return 0 if success, 1 if already initialized, -1 if failed
 */
int glite_config_reconfigure(const char * name);
    
/**
 * Finalize the Service using Glite Configuration
 * @return 0 if success, 1 if already finalized, -1 if failed
 */
int glite_config_finalize();

/**
 * Initialize variables for changing the process name. This method shoudl be
 * called in the main function passing the argc and argv arguments. It may be 
 * used to set the process name of forked child processes
 * @param argc [IN] the number of command line arguments
 * @param argv [IN] the command line arguments
 * @return the maximum length of the name that could be assigned
 */  
int glite_proc_name_init(int argc, char ** argv);

/**
 * Change the process name
 * @param name [IN] the name to assign to the process
 * @return the length of the name assigned to the process
 */
int glite_set_proc_name(const char * name);

#ifdef __cplusplus
}
#endif //__cplusplus

#endif //GLITE_DATA_CONFIG_GLITE_CONF_H_
